\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{neophysics}[2020/10/01 The Neophysics LaTeX class]
\LoadClassWithOptions{article}
%\setlength{\mathindent}{20pt}
\PassOptionsToPackage{
 paperheight =8.4in, % inherits from class
 paperwidth = 5.2in, % inherits from class
 inner = .2in , % default 36pt or 0.5in
 outer = .2in , % 36pt or 0.5in
 top = 0.2in, % 36pt or 0.5in
 bot = 0.2in, % 36pt or 0.5in
 binding = 12pt, % 9pt or 0.125in
 marginalgrid = 0 , % 3 it is just a number
 marginparsep = 0ex , % 3ex, if using sidenotesplus change to 4 or 5ex
 footskip= 15pt , % inherits from class
 extrafirstfoot=20pt, %adds height to first page footer
}{flexipage}
\RequirePackage{flexipage}


\PassOptionsToPackage{utf8}{inputenc}
\RequirePackage{inputenc}
\PassOptionsToPackage{T1}{fontenc} % T2A for cyrillics
\RequirePackage{fontenc}

%\usepackage[utopia]{mathdesign}
\PassOptionsToPackage{widespace}{fourier}
\RequirePackage[widespace]{fourier}
\RequirePackage{bm}
\linespread{1.05} % a bit more
\PassOptionsToPackage{ % and define script and nicer calagrapphic math fonts
scr=boondoxo,
scrscaled=1.10,
cal=stix,}{mathalpha}
\RequirePackage{mathalpha}
\usepackage[scale=0.88,defaultsans]{opensans}

\DeclareRobustCommand\ebseries{\fontseries{eb}\selectfont}
\DeclareRobustCommand\sbseries{\fontseries{sb}\selectfont}
\DeclareRobustCommand\ltseries{\fontseries{l}\selectfont}
\DeclareRobustCommand\clseries{\fontseries{lc}\selectfont}

\DeclareTextFontCommand{\texteb}{\ebseries}
\DeclareTextFontCommand{\textsb}{\sbseries}
\DeclareTextFontCommand{\textlt}{\ltseries}
\DeclareTextFontCommand{\textcl}{\clseries}

\global\parsep=0pt

\def\figurecaptionfont{\footnotesize}
\def\tablefont{\footnotesize}
\def\tablecaptionfont{\footnotesize}
\def\tabnotefont{\footnotesize}
\newbox\tempbox

% add kerning between letters of all cap fonts
\RequirePackage{microtype}
\SetTracking[name=locap,
 no ligatures,
 spacing = {600*,-100*, },
 outer spacing = {450,250,150},
 outer kerning = {*,*} ]
{ encoding = *, shape = sc }{50}
\RequirePackage{textcase}
\newcommand\textscUp[1]{\textls[70]{\scshape\MakeTextUppercase{#1}}}
\newcommand\textsclo[1]{\textls{\scshape\MakeTextLowercase{#1}}}
\newcommand\textscUl[1]{\textls{\scshape{#1}}}
\RequirePackage{setspace}
\PassOptionsToPackage{type={CC},modifier={by-nc-nd},version={4.0},imagemodifier={-80x15}}{doclicense}
\RequirePackage{doclicense}

\def\@longtitle{123}
\let\title\undefined
\DeclareRobustCommand\title{\@ifnextchar[{\@mytitle}{\@mytitle[]}}
\def\@mytitle[#1]#2{%
\let\@longtitle\undefined
\ifx&#1& \def\@shorttitle{#2} \else \def\@shorttitle{#1} \fi%
\def\@longtitle{#2}%
}

\let\author\undefined
\DeclareRobustCommand\author{\@ifnextchar[{\@myauthor}{\@myauthor[]}}
\def\@myauthor[#1]#2{%
\ifx&#1& \def\@shortauthor{#2} \else \def\@shortauthor{#1} \fi%
\def\@author{#2}%
}

\def\address#1{\ifx&#1&
  \def\@authoraddr{\setstretch{0.8}~\\}
\else
  \def\@authoraddr{{\setstretch{0.8}~\\ \small#1\\}}
\fi}
\address{}%and initialise

\def\contactemail#1{\ifx&#1&
  \def\@authoremail{}
\else
  \def\@authoremail{\textsf{\small#1}}
\fi}
\contactemail{}%and initialise

\def\copyrightauthor#1{\ifx&#1&
  \def\@copyrightauthor{The Above Authors}
\else
  \def\@copyrightauthor{#1}
\fi}
\copyrightauthor{}%and initialise

\def\keywords#1{\ifx&#1&
  \def\listkeywords{}
\else
  \def\listkeywords{#1}
\fi}
\keywords{}%and initialise

\def\@maketitle{%
  \newpage
  \begin{center}%
    {\fontsize{13}{13}\selectfont\bfseries \@longtitle \par}%
   \vskip 1em%
    { \@author\par}%
 \vskip 0em%
\@authoraddr
\@authoremail
   \vskip 0.1em%
    {\small \@date}%
  \end{center}%
  \par
 }

\newcommand\blindfootnote[1]{%
  \begingroup
  \renewcommand\thefootnote{}\footnote{#1}%
  \addtocounter{footnote}{-1}%
  \endgroup
}
\renewcommand{\@makefntext}[1]{%
 \begin{list}{}{\setlength{\labelwidth}{1.5em}%
 \setlength{\leftmargin}{\labelwidth}%
 \setlength{\listparindent}{1.5em}%
 \setlength{\labelsep}{3pt}%
 \setlength{\itemsep}{0pt}%
 \setlength{\parsep}{0pt}%
 \setlength{\topsep}{-2pt}%
 \setlength{\rightmargin}{20pt}%
 \setstretch{0.9}
 \footnotesize}%
 \item[\@thefnmark\hfil]#1%
 \end{list}%
}

\renewcommand\partname{}
\let\@part\undefined
\def\@part[#1]#2{%
      \refstepcounter{part}%
      \addcontentsline{toc}{part}{#1}%
    {\parindent \z@ \raggedright
     \interlinepenalty \@M
     \normalfont
     \centering\bfseries \textscUl{#2}%
     \markboth{}{}\par}%
    \nobreak
    \vskip 3ex
    \@afterheading}

%\renewcommand\section{\@startsection {section}{1}{-\parindent}%
%                                   {-4ex \@plus -1ex \@minus -.2ex}%
%                                   {2.3ex \@plus.2ex}%
%                                   {\normalfont\large\textscUl}}%
%\renewcommand\subsection{\@startsection{subsection}{2}{-\parindent}%
%                                     {-1ex\@plus -0.5ex \@minus -.2ex}%
%                                     {0.5ex \@plus .2ex}%
%                                     {\normalfont\textscUl}}%
%\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
%                                     {-1.0ex\@plus -0.5ex \@minus -.2ex}%
%                                     {0.5ex \@plus .2ex}%
%                                     {\normalfont\slshape}}%
%\renewcommand\paragraph{\@startsection{paragraph}{4}{-\parindent}%
%                                     {-1.0ex\@plus -0.5ex \@minus -.2ex}%
%                                     {-1em}%
%                                     {\normalfont\textscUl}}%
%\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
%                                     {-1.0ex\@plus -0.5ex \@minus -.2ex}%
%                                     {-1em}%
%                                     {\normalfont\textscUl}}%

\renewcommand\section{\@startsection {section}{1}{\z@}%
                                   {-4ex \@plus -1ex \@minus -1ex}%
                                   {2.0ex \@plus.5ex \@minus .5ex}%
                                   {\normalfont\bfseries}}%
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {-1ex\@plus -0.5ex \@minus -.2ex}%
                                     {0.5ex \@plus .2ex}%
                                     {\normalfont\itshape\bfseries}}%
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     {-1.0ex\@plus -0.5ex \@minus -.2ex}%
                                     {0.5ex \@plus .2ex}%
                                     {\normalfont\itshape}}%
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                     {-1.0ex\@plus -0.5ex \@minus -.2ex}%
                                     {-1em}%
                                     {\normalfont\bfseries}}%
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\z@}%
                                     {-1.0ex\@plus -0.5ex \@minus -.2ex}%
                                     {-1em}%
                                     {\normalfont\itshape}}%



\renewenvironment{abstract}{%
\small
\vspace{-0.5\baselineskip}
%\begin{center}%
%{\small\bfseries \abstractname\par}
%\end{center}%
%\vspace{-1.5\baselineskip}
\list{}{
\fontsize{9.5}{11}\selectfont
\leftmargin 3em
\rightmargin \leftmargin
 \setlength{\listparindent}{1.5em}%
 \setlength{\labelsep}{3pt}%
 \setlength{\itemsep}{4pt}%
 \setlength{\parsep}{0pt}%
 \setlength{\topsep}{2.3ex \@plus.2ex}%
%\parsep 0.3em \@plus\p@
}%
\parindent 1.8em
\item{\bfseries \abstractname: ~}\relax
}
{\ifx\listkeywords\@empty
{}\else\item{\bfseries Keywords: ~}\listkeywords\fi
\endlist}

\def\NeophysicsRef#1{\ifx&#1&
  \def\@hnprefeven{}
  \def\@hnprefodd{}
  \def\@hnpref{}
\else
  \def\@hnprefodd{#1~-~}
  \def\@hnprefeven{~-~#1}
  \def\@hnpref{/p/#1}
\fi}
\NeophysicsRef{}%and initialise

%\let\oldbib\bibliography
%\let\bibliography\undefined
%\def\bibliography#1{%
%\vskip 2.3ex \@plus.2ex
%\pdfbookmark[1]{References}{References}
%\oldbib{#1}%
%}
\RequirePackage{etoolbox}
%\patchcmd\thebibliography  %compacts the reference
% {\labelsep}
% {\labelsep\itemsep=0pt\parsep=3pt\relax}
% {}
% {\typeout{Couldn't patch the command}}
%\bibliographystyle{iopart-num}

\let\oldappendix\appendix
\let\appendix\undefined
\def\appendix{
\part{Apendix}
\numberwithin{equation}{section}
\oldappendix
}

\DeclareRobustCommand{\bmtitle}[1]{\bm{#1}}

\RequirePackage{hyperref}
\PassOptionsToPackage{open,openlevel=2,atend,numbered}{bookmark}
\pdfstringdefDisableCommands{%
  \renewcommand{\bmtitle}[1]{#1}%
}
\RequirePackage{bookmark}

\def\forproceedings#1{\ifx&#1&\def\@proceedings{}\else\def\@proceedings{Proceedings:\xspace}\fi}
\forproceedings{} %and initilise above
\fancyhf{} % fancy header already loaded in package flexipage
\fancyhead[EL]{}% gerade Seiten, links
\fancyhead[ER]{\textsc{\textscUl{\@proceedings Harbingers of
Neophysics}}\\\footnotesize\textsf{https://neophysics.org\@hnpref}}% gerade Seiten, rechts
\fancyhead[OL]{\small{\textscUl{\@shorttitle}}\\\small\@shortauthor}% ungerade Seiten, links
\fancyhead[OR]{}% ungerade Seiten, rechts
%\fancyfoot[EC]{\small\thepage\@hnprefeven}% gerade Seiten, rechts
%\fancyfoot[OC]{\small \@hnprefodd\thepage}% ungerade Seiten, links
%\fancyfoot[EC]{\small\thepage}% gerade Seiten, rechts
%\fancyfoot[OC]{\small\thepage}% ungerade Seiten, links
\fancyfoot[EC]{\small(\@hnprefodd\thepage)}% gerade Seiten, rechts
\fancyfoot[OC]{\small(\@hnprefodd\thepage)}% ungerade Seiten, links


\fancypagestyle{plain}{% first page
\fancyhf{}% clear all header and footer fields
\fancyfoot[L]{\footnotesize{{Copyright \noindent\copyright~\the\year, \@copyrightauthor; this work is
licensed under a
Creative Commons “Attribution-NonCommercial-NoDerivatives” license.
\raisebox{-5px}{\doclicenseImage[imagewidth=9em] %\includegraphics[scale=0.8]{by-nc-nd.eps}
}}}} % except the center
\renewcommand{\headrulewidth}{0pt}%
\renewcommand{\footrulewidth}{0pt}%
}

\RequirePackage[shortlabels]{enumitem}
\setlist{ parsep=0pt, listparindent=1.5em, topsep=6pt}
\setlist[itemize]{leftmargin=*,itemsep=3pt}
\setlist[enumerate]{leftmargin=1.5em,itemsep=3pt}
\setlist[description]{leftmargin=1.5em,itemsep=3pt}




%%%%%%%%%%%%%%%%%%%%%%%%%% Extract %%%%%%%%%%%%%%%%%%%%%%%
%%%
%%\newenvironment{quotation}
%%               {\list{}{\listparindent 1.5em%
%%                        \itemindent    \listparindent
%%                        \rightmargin   \leftmargin
%%                        \parsep        \z@ \@plus\p@}%
%%                \item\relax}
%%               {\endlist}
%%\newenvironment{quote}
%%               {\list{}{\rightmargin\leftmargin}%
%%                \item\relax}
%%               {\endlist}
%%%
%%\let\extract\quotation
%%\let\endextract\endquotation
%%%
%%\def\source#1{\par\hspace*{\fill}{\it#1}\par}
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Maths %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Floats %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
\def\FigName{figure}%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%\def\figurename{Fig.}
%%\newcounter{figure}
%\renewcommand\thefigure{\@arabic\c@figure}
%\def\fps@figure{tbp}
%\def\ftype@figure{1}
%\def\ext@figure{lof}
%\def\fnum@figure{\figurename~\thefigure}
%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%% Tables %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%\newcounter{table}
%\def\tablename{Table}
%\renewcommand\thetable{\@arabic\c@table}
%\def\fps@table{tbp}
%\def\ftype@table{2}
%\def\ext@table{lot}
%\def\fnum@table{\tablename~\thetable}

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
\def\tableformat#1{\centerline{#1}}
\newdimen\tabledim
\long\def\tbl#1#2{%
\global\setbox\tempbox\hbox{\tablefont #2}%
 \global\tabledim\wd\tempbox
 \tableformat{\vbox{\hsize\tabledim
                   \caption{\small#1}
                   \box\tempbox}}%
}


%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
\newenvironment{InTextTable}{%
 	\par\addvspace{16pt plus6pt minus6pt}%
 	\begin{center}
	\tablecaptionfont\noindent\ignorespaces
}{%
   	\end{center}
	\par\addvspace{17pt plus6pt minus6pt}}
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
\def\tabnotehead{Note}
\def\tabsourcehead{Source}
\newenvironment{tabnote}{%
   \par\addvspace{2pt}
   \setbox\tempbox\vbox\bgroup\hsize\tabledim\parindent12pt
   \tabnotefont
   \@ifnextchar[{\@tabnote}{\@tabnote[\tabnotehead]}%
}{%
		\par\egroup
   \tableformat{\box\tempbox}}
%
\def\@tabnote[#1]{\vskip6pt\noindent\def\@Tempa{#1}\ifx\@Tempa\@empty\hskip0pt\else{\it#1}:\hskip5pt\ignorespaces\fi}
%
%%
\newenvironment{tabfootnote}{%
   \par\addvspace{2pt}
   \setbox\tempbox\vbox\bgroup\hsize\tabledim\parindent12pt
   \tabnotefont
}{%
		\par\egroup
   \tableformat{\box\tempbox}}
%
%%
\def\tabmark#1{\noindent\hbox{\normalsize$\m@th^{#1}$}\ignorespaces}
%
\newenvironment{tabsource}{%
   \let\tabnotehead\tabsourcehead
   \begin{tabnote}
}{%
   \end{tabnote}
}
%
\def\Hline{%
  \noalign{\ifnum0=`}\fi\hrule \@height 2\arrayrulewidth \futurelet
   \@tempa\@xhline}
%
\def\x{@{\extracolsep{\fill}}}
\def\toprule{\Hline\\[-7.5pt]}
\def\colrule{\\[-7.5pt]\hline\\[-7.5pt]}
\def\TMcolrule{\\[-9.5pt]\hline\\[-9.5pt]}
\def\botrule{\\[-9pt]\Hline}
\def\crule#1{\\[-10pt]#1\\[-6pt]}
%
%%%%%%%%%%%%%%%%%%%%%%%% Caption %%%%%%%%%%%%%%%%%%%%%%%

%
%%%%%%%%%%%%%%%%%%%%%%%% Theorem %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

\RequirePackage{amsmath}

\global\mathindent=2em
%
\def\newtheorem#1{\@starthm{#1}\@ifnextchar[{\@othm{#1}}{\@nthm{#1}}}
\def\@xthm#1#2{\@opargbegintheorem{#2}{\csname the#1\endcsname}{}\ignorespaces}
\def\@nthm#1#2{\expandafter\gdef\csname #1name\endcsname{#2}%
\expandafter\gdef\csname #2bodyfont\endcsname{\csname #1bodyfont\endcsname}%
\@ifnextchar[{\@xnthm{#1}{#2}}{\@ynthm{#1}{#2}}}
\def\@othm#1[#2]#3{\expandafter\gdef\csname #1name\endcsname{#3}%
\expandafter\gdef\csname #3bodyfont\endcsname{\csname #1bodyfont\endcsname}%
  \@ifundefined{c@#2}{\@nocounterr{#2}}%
  {\expandafter\@ifdefinable\csname #1\endcsname
  {\global\@namedef{the#1}{\@nameuse{the#2}}%
		\global\@namedef{#1}{\@thm{#2}{#3}}%
		\global\@namedef{end#1}{\@endtheorem}}}}
\def\@opargbegintheorem#1#2#3{%
   \par\addvspace{3.25pt plus1pt minus.25pt}%
   \def\@tempa{#3}%
   {
	\noindent\sffamily\sbseries{#1 #2}\ifx\@tempa\empty\unskip:\else\unskip:\hskip.5em{(#3)}\fi}\hskip1em
	 \edef\@currentlabel{\csname p@#1\endcsname\csname the#1\endcsname}%
   \csname #1bodyfont\endcsname\ignorespaces}
\def\@endtheorem{\par\addvspace{3.25pt plus1pt minus.25pt}}
\def\@starthm#1{\@namedef{#1*}{\@beginstarthm{#1}}%
																\@namedef{end#1*}{\@endstarthm{#1}}}
\def\@beginstarthm#1{\@ifnextchar[{\@opargbeginstarthm{#1}}{\@opargbeginstarthm{#1}[]}}
\def\@opargbeginstarthm#1[#2]{\par\addvspace{3.25pt plus1pt minus.25pt}%
			   \renewcommand\labelenumi{{\upshape(\theenumi)}}%
			   \def\labelenumii{{\upshape(\theenumii)}}%
						\def\@tempa{#2}%
      \edef\@Tempa{\csname #1name\endcsname}%
			   {%\bfseries%\csname \@Tempa headfont\endcsname
      \noindent
      \ifx\@tempa\empty \sffamily\sbseries{\@Tempa{}:}\else \sffamily\sbseries{#2:}\fi}%
      \hskip1em\csname \@Tempa bodyfont\endcsname\ignorespaces}
\def\@endstarthm#1{\par\addvspace{3.25pt plus1pt minus.25pt}}
%
\DeclareRobustCommand{\qed}{%
  \ifmmode \mathqed
  \else
    \leavevmode\unskip\penalty9999 \hbox{}\nobreak\hfill
    \quad\hbox{\qedsymbol}%
  \fi
}
\let\QED@stack\@empty
\let\qed@elt\relax
\newcommand{\pushQED}[1]{%
  \toks@{\qed@elt{#1}}\@temptokena\expandafter{\QED@stack}%
  \xdef\QED@stack{\the\toks@\the\@temptokena}%
}
\newcommand{\popQED}{%
  \begingroup\let\qed@elt\popQED@elt \QED@stack\relax\relax\endgroup
}
\def\popQED@elt#1#2\relax{#1\gdef\QED@stack{#2}}
\newcommand{\qedhere}{%
  \begingroup \let\mathqed\math@qedhere
    \let\qed@elt\setQED@elt \QED@stack\relax\relax \endgroup
}
\newif\ifmeasuring@
\newif\iffirstchoice@ \firstchoice@true
\def\setQED@elt#1#2\relax{%
  \ifmeasuring@
  \else \iffirstchoice@ \gdef\QED@stack{\qed@elt{}#2}\fi
  \fi
  #1%
}
\def\qed@warning{%
  \PackageWarning{amsthm}{The \@nx\qedhere command may not work
    correctly here}%
}
\newcommand{\mathqed}{\quad\hbox{\qedsymbol}}
\def\linebox@qed{\hfil\hbox{\qedsymbol}\hfilneg}
\@ifpackageloaded{amsmath}{%
  \def\math@qedhere{%
    \@ifundefined{\@currenvir @qed}{%
      \qed@warning\quad\hbox{\qedsymbol}%
    }{%
      \@xp\aftergroup\csname\@currenvir @qed\endcsname
    }%
  }
  \def\displaymath@qed{%
    \relax
    \ifmmode
      \ifinner \aftergroup\linebox@qed
      \else
        \eqno
        \let\eqno\relax \let\leqno\relax \let\veqno\relax
        \hbox{\qedsymbol}%
      \fi
    \else
       \aftergroup\linebox@qed
    \fi
  }
  \@xp\let\csname equation*@qed\endcsname\displaymath@qed
  \def\equation@qed{%
    \iftagsleft@
      \hbox{\phantom{\quad\qedsymbol}}%
      \gdef\alt@tag{%
        \rlap{\hbox to\displaywidth{\hfil\qedsymbol}}%
        \global\let\alt@tag\@empty
      }%
    \else
      \gdef\alt@tag{%
        \global\let\alt@tag\@empty
        \vtop{\ialign{\hfil####\cr
                \tagform@\theequation\cr
                \qedsymbol\cr}}%
        \setbox\z@
      }%
    \fi
  }
  \def\qed@tag{%
    \global\tag@true \nonumber
    &\omit\setboxz@h {\strut@ \qedsymbol}\tagsleft@false
    \place@tag@gather
    \kern-\tabskip
    \ifst@rred \else \global\@eqnswtrue \fi \global\advance\row@\@ne \cr
  }
  \def\split@qed{%
    \def\endsplit{\crcr\egroup \egroup \ctagsplit@false \rendsplit@
      \aftergroup\align@qed
    }%
  }
  \def\align@qed{%
    \ifmeasuring@ \tag*{\qedsymbol}%
    \else \let\math@cr@@@\qed@tag
    \fi
  }
  \@xp\let\csname align*@qed\endcsname\align@qed
  \@xp\let\csname gather*@qed\endcsname\align@qed
%% Needs some patching up for amsmath 1.2
}{% end of amsmath branch, start plain LaTeX branch
  \def\math@qedhere{%
    \@ifundefined{\@currenvir @qed}{%
      \qed@warning \aftergroup\displaymath@qed
    }{%
      \@xp\aftergroup\csname\@currenvir @qed\endcsname
    }%
  }
  \def\displaymath@qed{%
    \relax
    \ifmmode
      \ifinner \aftergroup\aftergroup\aftergroup\linebox@qed
      \else
        \eqno \def\@badmath{$$}%
        \let\eqno\relax \let\leqno\relax \let\veqno\relax
        \hbox{\qedsymbol}%
      \fi
    \else
       \aftergroup\linebox@qed
    \fi
  }
  \@ifundefined{ver@leqno.clo}{%
    \def\equation@qed{\displaymath@qed \quad}%
  }{%
    \def\equation@qed{\displaymath@qed}%
  }
  \def\@tempa#1$#2#3\@nil{%
    \def\[{#1$#2\def\@currenvir{displaymath}#3}%
  }%
  \expandafter\@tempa\[\@nil
}
\@ifpackageloaded{amstex}{%
  \def\@tempa{TT}%
}{%
  \@ifpackageloaded{amsmath}{%
    \def\@tempb#1 v#2.#3\@nil{#2}%
    \ifnum\@xp\@xp\@xp\@tempb\csname ver@amsmath.sty\endcsname v0.0\@nil
       <\tw@
      \def\@tempa{TT}%
    \else
      \def\@tempa{TF}%
    \fi
  }{%
    \def\@tempa{TF}
  }%
}
\if\@tempa
  \renewcommand{\math@qedhere}{\quad\hbox{\qedsymbol}}%
\fi
\newcommand{\openbox}{\leavevmode
  \hbox to.77778em{%
  \hfil\vrule
  \vbox to.675em{\hrule width.6em\vfil\hrule}%
  \vrule\hfil}}
\DeclareRobustCommand{\textsquare}{%
  \begingroup \usefont{U}{msa}{m}{n}\thr@@\endgroup
}
\providecommand{\qedsymbol}{\openbox}
\newenvironment{proof}[1][\proofname]{\par\addvspace{3.25pt plus1pt minus.25pt}
  \pushQED{\qed}%
  \normalfont \topsep0\p@\@plus0\p@\relax
  \trivlist
  \item[\hskip\labelsep
%  \bf
    \sffamily\sbseries{#1}\@addpunct{:}]\ignorespaces
}{%
  \popQED\endtrivlist\@endpefalse
}
\providecommand{\proofname}{Proof}
%




\def\sectionTheoremNumbers{
\newtheorem{theorem}{Theorem}[section]
\newcommand\theorembodyfont{\slshape}
\newtheorem{lemma}{Lemma}[section]
\newcommand\lemmabodyfont{\slshape}
\newtheorem{proposition}{Proposition}[section]
\newcommand\propositionbodyfont{\slshape}
\newtheorem{corollary}{Corollary}[section]
\newcommand\corollarybodyfont{\slshape}
\newtheorem{assertion}{Assertion}[section]
\newcommand\assertionbodyfont{\slshape}
\newtheorem{axiom}{Axiom}[section]
\newcommand\axiombodyfont{\slshape}
\newtheorem{observation}{Observation}[section]
\newcommand\observationbodyfont{\slshape}
%
\newtheorem{algorithm}{Algorithm}[section]
\newcommand\algorithmbodyfont{\upshape}
\newtheorem{answer}{Answer}[section]
\newcommand\answerbodyfont{\upshape}
\newtheorem{assumption}{Assumption}[section]
\newcommand\assumptionbodyfont{\upshape}
\let\comment\undefined
\newtheorem{comment}{Comment}[section]
\newcommand\commentbodyfont{\upshape}
\newtheorem{definition}{Definition}[section]
\newcommand\definitionbodyfont{\upshape}
\newtheorem{example}{Example}[section]
\newcommand\examplebodyfont{\upshape}
\newtheorem{remark}{Remark}[section]
\newcommand\remarkbodyfont{\upshape}
\newtheorem{solution}{Solution}[section]
\newcommand\solutionbodyfont{\upshape}
}
%
\def\plainTheoremNumbers{
\newtheorem{theorem}{Theorem}%[section]
\newcommand\theorembodyfont{\slshape}
\newtheorem{lemma}{Lemma}%[section]
\newcommand\lemmabodyfont{\slshape}
\newtheorem{proposition}{Proposition}%[section]
\newcommand\propositionbodyfont{\slshape}
\newtheorem{corollary}{Corollary}%[section]
\newcommand\corollarybodyfont{\slshape}
\newtheorem{assertion}{Assertion}%[section]
\newcommand\assertionbodyfont{\slshape}
\newtheorem{axiom}{Axiom}%[section]
\newcommand\axiombodyfont{\slshape}
\newtheorem{observation}{Observation}%[section]
\newcommand\observationbodyfont{\slshape}
%
\newtheorem{algorithm}{Algorithm}%[section]
\newcommand\algorithmbodyfont{\upshape}
\newtheorem{answer}{Answer}%[section]
\newcommand\answerbodyfont{\upshape}
\newtheorem{assumption}{Assumption}%[section]
\newcommand\assumptionbodyfont{\upshape}
\let\comment\undefined
\newtheorem{comment}{Comment}%[section]
\newcommand\commentbodyfont{\upshape}
\newtheorem{definition}{Definition}%[section]
\newcommand\definitionbodyfont{\upshape}
\newtheorem{example}{Example}%[section]
\newcommand\examplebodyfont{\upshape}
\newtheorem{remark}{Remark}%[section]
\newcommand\remarkbodyfont{\upshape}
\newtheorem{solution}{Solution}%[section]
\newcommand\solutionbodyfont{\upshape}
}


 \DeclareMathSizes{7}{7}{5}{5}
 \DeclareMathSizes{8}{8}{7}{6}
 \DeclareMathSizes{9}{9}{7.5}{6.5}
 \DeclareMathSizes{\@xpt}{\@xpt}{7.8}{6.8}
 \DeclareMathSizes{\@xipt}{\@xipt}{8}{7}
 \DeclareMathSizes{\@xiipt}{\@xiipt}{9}{7.5}

\RequirePackage{xspace}
 \newcommand{\ie}{\textit{i.\:\!e. }\xspace}
 \newcommand{\Ie}{\textit{I.\:\!e. }\xspace}
 \newcommand{\eg}{\textit{e.\:\!g. }\xspace}
 \newcommand{\Eg}{\textit{E.\:\!g. }\xspace}
 \newcommand{\etc}{\textit{etc. }\xspace}

 \newcommand\pdfhypersetup{
    \hypersetup{
    pdftoolbar=true,        % show Acrobat’s toolbar?
    pdfmenubar=true,        % show Acrobat’s menu?
    pdftitle={\@longtitle},    % title
    pdfauthor={\@shortauthor},     % author
    pdfsubject={},   % subject of the document
    pdfkeywords={\listkeywords}, % list of keywords
    pdfnewwindow=true,      % links in new window
    colorlinks=true,       % false: boxed links; true: colored links
    linkcolor=black,       % color of internal links (change box color with linkbordercolor)
    citecolor=black,       % color of links to bibliography
    filecolor=black,       % color of file links
    urlcolor=black,         % color of external links
    pdfstartpage=1,         % open page 1
    pdfpagemode=UseOutlines, % and show bookmarks
    pdfstartview={XYZ null null 1} } % and set zoom to 100%
}
